==> chromium-browser_13.0.782.220~r99552.orig.tar.bz2: chromium-13.0.782.220~r99552/src/chrome/test/webdriver/commands/set_timeout_commands.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_TEST_WEBDRIVER_COMMANDS_SET_TIMEOUT_COMMANDS_H_
#define CHROME_TEST_WEBDRIVER_COMMANDS_SET_TIMEOUT_COMMANDS_H_

#include <string>
#include <vector>

#include "chrome/test/webdriver/commands/webdriver_command.h"

class DictionaryValue;

namespace webdriver {

class Response;

class SetTimeoutCommand : public WebDriverCommand {
 public:
  SetTimeoutCommand(const std::vector<std::string>& path_segments,
                    const DictionaryValue* const parameters);
  virtual ~SetTimeoutCommand();

  virtual bool DoesPost();
  virtual void ExecutePost(Response* const response);
  virtual void SetTimeout(int timeout_ms) = 0;

 private:
  DISALLOW_COPY_AND_ASSIGN(SetTimeoutCommand);
};

// Set timeout for asynchronous script execution (/session/*/execute_async).
class SetAsyncScriptTimeoutCommand : public SetTimeoutCommand {
 public:
  SetAsyncScriptTimeoutCommand(const std::vector<std::string>& path_segments,
                               const DictionaryValue* const parameters);
  virtual ~SetAsyncScriptTimeoutCommand();
  virtual void SetTimeout(int timeout_ms);

 private:
  DISALLOW_COPY_AND_ASSIGN(SetAsyncScriptTimeoutCommand);
};

// Set the amount of time the driver should wait when searching for elements.
class ImplicitWaitCommand : public SetTimeoutCommand {
 public:
  ImplicitWaitCommand(const std::vector<std::string>& path_segments,
                      const DictionaryValue* const parameters);
  virtual ~ImplicitWaitCommand();
  virtual void SetTimeout(int timeout_ms);

 private:
  DISALLOW_COPY_AND_ASSIGN(ImplicitWaitCommand);
};

}  // namespace webdriver

#endif  // CHROME_TEST_WEBDRIVER_COMMANDS_SET_TIMEOUT_COMMANDS_H_

==> chromium-browser_14.0.835.163~r101024.orig.tar.bz2: chromium-14.0.835.163~r101024/src/chrome/test/webdriver/commands/set_timeout_commands.h <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_TEST_WEBDRIVER_COMMANDS_SET_TIMEOUT_COMMANDS_H_
#define CHROME_TEST_WEBDRIVER_COMMANDS_SET_TIMEOUT_COMMANDS_H_

#include <string>
#include <vector>

#include "chrome/test/webdriver/commands/webdriver_command.h"

namespace base {
class DictionaryValue;
}

namespace webdriver {

class Response;

class SetTimeoutCommand : public WebDriverCommand {
 public:
  SetTimeoutCommand(const std::vector<std::string>& path_segments,
                    const base::DictionaryValue* const parameters);
  virtual ~SetTimeoutCommand();

  virtual bool DoesPost();
  virtual void ExecutePost(Response* const response);
  virtual void SetTimeout(int timeout_ms) = 0;

 private:
  DISALLOW_COPY_AND_ASSIGN(SetTimeoutCommand);
};

// Set timeout for asynchronous script execution (/session/*/execute_async).
class SetAsyncScriptTimeoutCommand : public SetTimeoutCommand {
 public:
  SetAsyncScriptTimeoutCommand(const std::vector<std::string>& path_segments,
                               const base::DictionaryValue* const parameters);
  virtual ~SetAsyncScriptTimeoutCommand();
  virtual void SetTimeout(int timeout_ms);

 private:
  DISALLOW_COPY_AND_ASSIGN(SetAsyncScriptTimeoutCommand);
};

// Set the amount of time the driver should wait when searching for elements.
class ImplicitWaitCommand : public SetTimeoutCommand {
 public:
  ImplicitWaitCommand(const std::vector<std::string>& path_segments,
                      const base::DictionaryValue* const parameters);
  virtual ~ImplicitWaitCommand();
  virtual void SetTimeout(int timeout_ms);

 private:
  DISALLOW_COPY_AND_ASSIGN(ImplicitWaitCommand);
};

}  // namespace webdriver

#endif  // CHROME_TEST_WEBDRIVER_COMMANDS_SET_TIMEOUT_COMMANDS_H_
